// Copyright (c) 2022, Frappe Technologies Pvt. Ltd. and contributors
// For license information, please see license.txt
/* eslint-disable */

function get_filters() {
	let filters = [
		{
			"fieldname":"company",
			"label": __("Company"),
			"fieldtype": "Link",
			"options": "Company",
			"default": frappe.defaults.get_user_default("Company"),
			"reqd": 1
		},
		{
			"fieldname":"period_start_date",
			"label": __("Start Date"),
			"fieldtype": "Date",
			"reqd": 1,
			"default": frappe.datetime.add_months(frappe.datetime.get_today(), -1)
		},
		{
			"fieldname":"period_end_date",
			"label": __("End Date"),
			"fieldtype": "Date",
			"reqd": 1,
			"default": frappe.datetime.get_today()
		},
		{
			"fieldname":"sales_order",
			"label": __("Sales Order"),
			"fieldtype": "MultiSelectList",
			"width": 100,
			"options": "Sales Order",
			"get_data": function(txt) {
				return frappe.db.get_link_options("Sales Order", txt, this.filters());
			},
			"filters": () => {
				return {
					docstatus: 1,
					payment_terms_template: ['not in', ['']],
					company: frappe.query_report.get_filter_value("company"),
					transaction_date: ['between', [frappe.query_report.get_filter_value("period_start_date"), frappe.query_report.get_filter_value("period_end_date")]]
				}
			},
			on_change: function(){
				frappe.query_report.refresh();
			}
		}
	]

	return filters;
}

frappe.query_reports["Payment Terms Status for Sales Order"] = {
	"filters": get_filters(),
	"formatter": function(value, row, column, data, default_formatter){
		if(column.fieldname == 'invoices' && value) {
			invoices = value.split(',');
			const invoice_formatter = (prev_value, curr_value) => {
				if(prev_value != "") {
					return prev_value + ", " + default_formatter(curr_value, row, column, data);
				}
				else {
					return default_formatter(curr_value, row, column, data);
				}
			}
			return invoices.reduce(invoice_formatter, "")
		}
		else if (column.fieldname == 'paid_amount' && value){
			formatted_value = default_formatter(value, row, column, data);
			if(value > 0) {
				formatted_value = "<span style='color:green;'>" + formatted_value + "</span>"
			}
			return formatted_value;
		}
		else if (column.fieldname == 'status' && value == 'Completed'){
			return "<span style='color:green;'>" + default_formatter(value, row, column, data) + "</span>";
		}

		return default_formatter(value, row, column, data);
	},

};
